<?php

namespace App\Livewire\Admin;

use Livewire\Component;
use App\Models\Bien;
use Flux\Flux;
use Livewire\WithPagination;
use Illuminate\Support\Facades\Auth;
use Livewire\WithFileUploads;
class BiensComponent extends Component
{
    use WithPagination;
    use WithFileUploads;
    public $isOpen = false;
    public $item;
    public $search = '';
    public $bienToChangeStatut;
    public $imagesBienToShow = [];
    public $imagesToAdd = [];
    public $departements = ["Dakar","Pikine","Guédiawaye","Rufisque","Thiès","Mbour","Tivaouane","Saint-Louis","Podor","Dagana","Louga","Kébémer",
        "Linguère","Kaolack","Nioro du Rip","Guinguinéo","Ziguinchor","Bignona","Oussouye","Tambacounda","Bakel","Goudiry","Koumpentoum","Kolda","Vélingara",
        "Médina Yoro Foulah","Matam","Kanel","Ranérou-Ferlo","Fatick","Foundiougne","Gossas","Kaffrine","Birkilane","Koungheul","Malem Hodar","Kédougou","Salémata",
        "Saraya","Sédhiou","Bounkiling","Goudomp","Diourbel","Bambey","Mbacké","Koungheul"
    ];
    
    protected function rules() 
    {
        return [
            'item.titre' => 'required|string|max:255',
            'item.description' => 'required|string',
            'item.type' => 'required|string|in:appartement,villa,terrain',
            'item.localisation' => 'required|string|max:255',
            'item.prix' => 'required|numeric|min:0',
            'item.nombre_garages' => 'nullable',
            'item.annee_construction' => 'nullable',
            'item.type_papier' => 'nullable',
            'item.source_video' => 'nullable',
            'item.superficie' => 'required|integer|min:1',
            'item.nombre_pieces' => 'requiredIF:item.type,villa',
            'item.nombre_salles_bain' => 'requiredIF:item.type,villa,appartement',
            'item.statut' => 'required|string|in:disponible,vendu',
            'item.departement' => 'required|string|in:'.implode(',', $this->departements),
            'item.premium' => 'required|boolean',
        ];
    }
        
    
    
    protected function messages() 
    {
        return [
            'item.nombre_pieces.required' => 'Le nombre de pièces est requis pour les villas',
            'item.nombre_salles_bain.required' => 'Le nombre de salles de bain est requis pour les villas et les appartements',
        ];
    }

    public function updateStatut($id)
    {
        $bien = Bien::find($id);
        if ($bien) {
            $this->bienToChangeStatut = $bien;
            Flux::modal('change-statut')->show();
        }
    }

    public function changeStatut()
    {
        $this->bienToChangeStatut->statut = $this->bienToChangeStatut->statut === 'disponible' ? 'vendu' : 'disponible';
        $this->bienToChangeStatut->save();
        Flux::toast(
            heading: 'Statut changé',
            text: 'Le statut du bien a été changé avec succès.',
            variant: 'success'
        );
        $this->bienToChangeStatut = null;
        Flux::modal('change-statut')->close();
    }
    public function openModalImages($id)
    {
        $this->bienToChangeStatut = Bien::find($id);
        $this->imagesBienToShow = $this->bienToChangeStatut->images;
        Flux::modal('images-bien')->show();
    }
    public function saveImages()
    {
        foreach ($this->imagesToAdd as $image) {
            $this->bienToChangeStatut->images()->create([
                'url' => $image->store('images', 'public'),
            ]);
        }
        $this->imagesToAdd = [];
        $this->imagesBienToShow = $this->bienToChangeStatut->images;
    }
    public function mount()
    {
        $this->item = new Bien();
    }
    
    public function openModal($id = null)
    {
        $this->isOpen = true;
        $this->item = Bien::find($id);
        if(empty($this->item)){
            $this->item = new Bien();
            $this->item->premium = false;
        }
        Flux::modal('form-bien')->show();
    }
    
    public function confirmDelete($id)
    {
        $bien = Bien::find($id);
        if ($bien) {
            Flux::confirm(
                heading: 'Êtes-vous sûr?',
                text: "Voulez-vous vraiment supprimer ce bien immobilier?",
                variant: 'danger',
                confirm: 'Oui, supprimer',
                cancel: 'Annuler'
            )->then(function () use ($id) {
                $this->delete($id);
            });
        }
    }
    
    public function delete($id)
    {
        $bien = Bien::find($id);
        if ($bien) {
            $bien->delete();
            Flux::toast(
                heading: 'Suppression réussie',
                text: 'Le bien immobilier a été supprimé avec succès.',
                variant: 'success'
            );
        }
    }

    public function save()
    {
        $this->validate();
        
        if (!$this->item->id) {
            $this->item->added_by = Auth::id();
        }
        
        $this->item->save();
        
        Flux::toast(
            heading: 'Enregistrement réussi',
            text: 'Les informations du bien immobilier ont été enregistrées.',
            variant: 'success'
        );
        
        Flux::modal('form-bien')->close();
    }

    public function render()
    {
        return view('livewire.admin.biens-component', [
            'biens' => Bien::where('titre', 'like', '%'.$this->search.'%')
                ->orWhere('localisation', 'like', '%'.$this->search.'%')
                ->paginate(10),
        ]);
    }
}
