<?php

namespace App\Livewire\Admin;

use Livewire\Component;
use App\Models\Demande;
use App\Models\SuiviDemande;
use Flux\Flux;
use Livewire\WithPagination;
use Illuminate\Support\Facades\Auth;
use Livewire\WithFileUploads;

class DemandesComponent extends Component
{
    use WithPagination;
    use WithFileUploads;

    public $isOpen = false;
    public $itemSuivi;
    public $search = '';
    public $demandeToChangeStatut;
    public $suivisDemande;

    protected function rules() 
    {
        return [
            'itemSuivi.commentaire' => 'required|string',
            'itemSuivi.statut' => 'required|string',
        ];
    }

   
    public function updateStatut($demande_id, $statut)
    {
        $demande = Demande::find($demande_id);
        $demande->statut = $statut;
        $demande->save();
        Flux::toast(
            heading: 'Statut changé',
            text: 'Le statut de la demande a été changé avec succès.',
            variant: 'success'
        );
    }

    public function saveSuivi()
    {
        $this->validate();
        $this->itemSuivi->demande_id = $this->suivisDemande->id;
        $this->itemSuivi->user_id = Auth::id();
        $this->itemSuivi->save();
        $this->suivisDemande->statut = $this->itemSuivi->statut;
        $this->suivisDemande->save();
        Flux::toast(heading: 'Suivi enregistré', text: 'Le suivi a été enregistré avec succès.', variant: 'success');
    }

    

    

    public function openModalSuivi($id = null)
    {
        $this->isOpen = true;
        $this->suivisDemande = Demande::with('suivis.user')->find($id);
        $this->itemSuivi = new SuiviDemande();
        
        Flux::modal('suivi-demande')->show();
    }

    public function confirmDelete($id)
    {
        $demande = Demande::find($id);
        if ($demande) {
            Flux::confirm(
                heading: 'Êtes-vous sûr?',
                text: "Voulez-vous vraiment supprimer cette demande?",
                variant: 'danger',
                confirm: 'Oui, supprimer',
                cancel: 'Annuler'
            )->then(function () use ($id) {
                $this->delete($id);
            });
        }
    }

    public function delete($id)
    {
        $demande = Demande::find($id);
        if ($demande) {
            $demande->delete();
            Flux::toast(
                heading: 'Suppression réussie',
                text: 'La demande a été supprimée avec succès.',
                variant: 'success'
            );
        }
    }

    public function save()
    {
        $this->validate();

        if (!$this->item->id) {
            $this->item->added_by = Auth::id();
        }

        $this->item->save();

        Flux::toast(
            heading: 'Enregistrement réussi',
            text: 'Les informations de la demande ont été enregistrées.',
            variant: 'success'
        );

        Flux::modal('form-demande')->close();
    }

    public function render()
    {
        $total_demandes = Demande::count();
        $total_demandes_en_attente = Demande::where('statut', 'En attente')->count();
        $total_demandes_en_cours = Demande::where('statut', 'En cours')->count();
        $total_demandes_traitées = Demande::where('statut', 'Traitée')->count();
        $total_demandes_annulées = Demande::where('statut', 'Annulée')->count();
        return view('livewire.admin.demandes-component', [
            'demandes' => Demande::where('nom', 'like', '%'.$this->search.'%')
                ->orWhere('email', 'like', '%'.$this->search.'%')
                ->orWhere('telephone', 'like', '%'.$this->search.'%')
                ->paginate(10),
            'total_demandes' => $total_demandes,
            'total_demandes_en_attente' => $total_demandes_en_attente,
            'total_demandes_en_cours' => $total_demandes_en_cours,
            'total_demandes_traitées' => $total_demandes_traitées,
            'total_demandes_annulées' => $total_demandes_annulées,
        ]);
    }
}
