<?php

namespace App\Livewire\Admin;

use Livewire\Component;
use App\Models\Faq;
use Flux\Flux;
use Livewire\WithPagination;
use Illuminate\Support\Facades\Auth;
class FaqsComponent extends Component
{
    use WithPagination;
    public $isOpen = false;
    public $item;
    public $search = '';

    protected $rules = [
        'item.question' => 'required|string|max:255',
        'item.answer' => 'required|string',
    ];

    public function mount()
    {
        $this->item = new Faq();
        Flux::modal('form-faq')->show();
        Flux::toast('Vos modifications ont été enregistrées.');
    }

    public function openModal($id = null)
    {
        $this->isOpen = true;
        $this->item = Faq::find($id);
        if (empty($this->item)) {
            $this->item = new Faq();
        }
        Flux::modal('form-faq')->show();
    }

    public function save()
    {
        $this->validate();
        $this->item->save();
        Flux::toast(
            heading: 'Enregistrement réussi.',
            text: 'Vous pouvez modifier les informations de la FAQ.',
            variant: 'success',
        );
        Flux::modal('form-faq')->close();
    }
    public function confirmDelete($id)
    {
        $faq = Faq::find($id);
        if ($faq) {
            Flux::confirm(
                heading: 'Êtes-vous sûr?',
                text: "Voulez-vous vraiment supprimer cette FAQ?",
                variant: 'danger',
                confirm: 'Oui, supprimer',
                cancel: 'Annuler'
            )->then(function () use ($id) {
                $this->delete($id);
            });
        }
    }

    public function render()
    {
        return view('livewire.admin.faqs-component', [
            'faqs' => Faq::where('question', 'like', '%' . $this->search . '%')->paginate(10),
        ]);
    }
}
