<?php

namespace App\Livewire\Admin;

use Livewire\Component;
use App\Models\Testimonial;
use Flux\Flux;
use Livewire\WithPagination;
use Illuminate\Support\Facades\Auth;

class TestimonialsComponent extends Component
{
    use WithPagination;
    public $isOpen = false;
    public $item;
    public $search = '';
    public $testimonialToDelete;

    protected $rules = [
        'item.name' => 'required|string|max:255',
        'item.testimonial' => 'required|string',
        'item.rating' => 'required|integer|min:1|max:5',
    ];

    public function mount()
    {
        $this->item = new Testimonial();
        Flux::modal('form-testimonial')->show();
        Flux::toast('Vos modifications ont été enregistrées.');
    }

    public function openModal($id = null)
    {
        $this->isOpen = true;
        $this->item = Testimonial::find($id);
        if (empty($this->item)) {
            $this->item = new Testimonial();
            $this->item->rating = 5;
        }
        Flux::modal('form-testimonial')->show();
    }

    public function save()
    {
        $this->validate();
        $this->item->save();
        Flux::toast(
            heading: 'Enregistrement réussi.',
            text: 'Vous pouvez modifier les informations du témoignage.',
            variant: 'success',
        );
        Flux::modal('form-testimonial')->close();
    }

    public function confirmDelete($id)
    {
        $testimonial = Testimonial::find($id);
        if ($testimonial) {
            $this->testimonialToDelete = $testimonial;
            Flux::modal('delete-testimonial')->show();

        }
    }
    

    public function delete()
    {
        $this->testimonialToDelete->delete();
        Flux::modal('delete-testimonial')->close();
        Flux::toast('Témoignage supprimé avec succès.');
    }

    public function render()
    {
        return view('livewire.admin.testimonials-component', [
            'testimonials' => Testimonial::where('name', 'like', '%' . $this->search . '%')->paginate(10),
        ]);
    }
}
