<?php

namespace App\Livewire\Admin;

use Livewire\Component;
use App\Models\User;
use Flux\Flux;
use Illuminate\Support\Facades\Hash;
use Livewire\WithPagination;
class UsersComponent extends Component
{
    use WithPagination;
    public $isOpen = false;
    public $item;
    public $search = '';
    public $password = '';
    public $password_confirmation = '';
    public $roles = [
        'admin' => 'Administrateur',
        'user' => 'Utilisateur',
    ];

    protected $rules = [
        'item.name' => 'required|string|max:255',
        'item.email' => 'required|email',
        'item.role' => 'required|string|in:admin,user',
        'item.phone' => 'nullable|string|max:255',
        'password' => 'nullable|string|min:8|confirmed',
    ];

    public function mount()
    {
        $this->item = new User();
        


    }
    
    public function openModal($id = null)
    {
        $this->isOpen = true;
        $this->item = User::find($id);
        if(empty($this->item)){
            $this->item = new User();
        }
        Flux::modal('form-user')->show();

    }

    public function save()
    {
       

        $validated = $this->validate();
        $this->item->email = strtolower($this->item->email);
        $this->validate([
            'item.email' => 'required|email|unique:users,email,'.$this->item->id,
        ]);
        if($this->password){
            $this->item->password = Hash::make($this->password);
        }
        $this->item->save();
        Flux::toast(
            heading: 'Enregistrement réussi.',
            text: 'Vous pouvez modifier les informations de l\'utilisateur.',
            variant: 'success',
        );
        Flux::modal('form-user')->close();
    }

    public function render()
    {
        return view('livewire.admin.users-component',[
            'users' => User::where('name', 'like', '%'.$this->search.'%')->paginate(10),
        ]);
    }
}
