<div>
    <h2 class="text-2xl font-bold">Liste des biens immobiliers</h2>

    <div
        class="flex flex-column sm:flex-row flex-wrap space-y-4 sm:space-y-0 items-center justify-between pb-4 mb-4 mt-4">
        <label for="table-search" class="sr-only">Rechercher</label>
        <div class="relative">
            <div class="absolute inset-y-0 left-0 rtl:inset-r-0 rtl:right-0 flex items-center ps-3 pointer-events-none">
                <svg class="w-5 h-5 text-gray-500 dark:text-gray-400" aria-hidden="true" fill="currentColor"
                    viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
                    <path fill-rule="evenodd"
                        d="M8 4a4 4 0 100 8 4 4 0 000-8zM2 8a6 6 0 1110.89 3.476l4.817 4.817a1 1 0 01-1.414 1.414l-4.816-4.816A6 6 0 012 8z"
                        clip-rule="evenodd"></path>
                </svg>
            </div>
            <flux:input icon="magnifying-glass" placeholder="Rechercher un bien" wire:model.live="search" clearable />
        </div>
        <flux:button variant="primary" wire:click="openModal">Ajouter un bien</flux:button>
    </div>
    <div class="shadow-md sm:rounded-lg relative overflow-x-auto p-4">

        <flux:table :paginate="$biens">
            <flux:table.columns>
                <flux:table.column>Titre</flux:table.column>
                <flux:table.column>Type</flux:table.column>
                <flux:table.column>Localisation</flux:table.column>
                <flux:table.column>Prix</flux:table.column>
                <flux:table.column>Disponibilité</flux:table.column>
                <flux:table.column>Premium</flux:table.column>
                <flux:table.column>Images</flux:table.column>
                <flux:table.column>Action</flux:table.column>
            </flux:table.columns>

            <flux:table.rows>
                @foreach ($biens as $bien)
                    <flux:table.row :key="$bien->id">
                        <flux:table.cell class="flex items-center gap-3">
                            {{ $bien->titre }}
                        </flux:table.cell>
                        <flux:table.cell>{{ $bien->type }}</flux:table.cell>
                        <flux:table.cell>{{ $bien->localisation }}</flux:table.cell>
                        <flux:table.cell>{{ number_format($bien->prix, 2, ',', ' ') }} F CFA</flux:table.cell>

                        <flux:table.cell>
                            <flux:switch label="Vendu" align="left" :checked="$bien->statut === 'vendu'"
                                wire:click="updateStatut({{ $bien->id }})" />
                        </flux:table.cell>
                        <flux:table.cell>
                            @if ($bien->premium)
                                <flux:badge color="yellow">Premium</flux:badge>
                            @else
                                <flux:badge color="gray">Standard</flux:badge>
                            @endif
                        </flux:table.cell>
                        <flux:table.cell>
                            <flux:button variant="teal" wire:click="openModalImages({{ $bien->id }})">
                                <flux:icon name="photo" class="w-4 h-4" />
                            </flux:button>
                        </flux:table.cell>
                        
                        <flux:table.cell>
                            <div class="flex gap-2">
                                <flux:button wire:click="openModal({{ $bien->id }})">Modifier</flux:button>
                                <flux:button variant="danger" wire:click="confirmDelete({{ $bien->id }})">
                                    <flux:icon name="trash" class="w-4 h-4" />
                                </flux:button>
                            </div>
                        </flux:table.cell>
                    </flux:table.row>
                @endforeach
            </flux:table.rows>
        </flux:table>
    </div>
    <flux:modal name="form-bien" class="w-2/3" variant="flyout">
        <div class="space-y-6">
            <div>
                <flux:heading size="lg">
                    @if ($item->id)
                        Modifier un bien immobilier
                    @else
                        Ajouter un bien immobilier
                    @endif
                </flux:heading>
            </div>
            <form wire:submit.prevent="save">
                <div class="grid grid-cols-2 gap-4">
                    <div>
                        <flux:input label="Titre" wire:model.live="item.titre" placeholder="Titre du bien" />
                    </div>
                    <div>
                        <flux:select variant="listbox" label="Type" placeholder="Sélectionnez un type..."
                            wire:model.live="item.type">
                            <flux:select.option value="villa">
                                <div class="flex items-center gap-2">
                                    <flux:icon.home variant="mini" class="text-zinc-400" /> Villa
                                </div>
                            </flux:select.option>
                            <flux:select.option value="appartement">
                                <div class="flex items-center gap-2">
                                    <flux:icon.arrow-left-end-on-rectangle variant="mini" class="text-zinc-400" /> Appartement
                                </div>
                            </flux:select.option>
                            <flux:select.option value="terrain">
                                <div class="flex items-center gap-2">
                                    <flux:icon.document-text variant="mini" class="text-zinc-400" /> Terrain
                                </div>
                            </flux:select.option>
                        </flux:select>
                    </div>
                    <div class="col-span-2">
                        <flux:editor label="Description" wire:model.live="item.description"
                            placeholder="Description du bien" rows="4" />
                    </div>
                    <div>
                        <flux:input label="Localisation" wire:model.live="item.localisation"
                            placeholder="Adresse du bien" />
                    </div>
                    <div>   
                        <flux:select variant="listbox" label="Département" searchable placeholder="Sélectionnez un département..."
                            wire:model.live="item.departement">
                            @foreach ($departements as $departement)
                                <flux:select.option value="{{ $departement }}">{{ $departement }}</flux:select.option>
                            @endforeach
                        </flux:select>
                    </div>

                    <div>
                        <flux:input label="Superficie" type="number" wire:model.live="item.superficie"
                            placeholder="Superficie en m²" />
                    </div>
                    <div>
                        <flux:input label="Nombre de pièces" type="number" wire:model.live="item.nombre_pieces"
                            placeholder="Nombre de pièces" />
                    </div>
                    <div>
                        <flux:input label="Nombre de salles de bain" type="number"
                            wire:model.live="item.nombre_salles_bain" placeholder="Nombre de salles de bain" />
                    </div>
                    <div>
                        <flux:input label="Prix" type="number" step="0.01" wire:model.live="item.prix"
                            placeholder="Prix en euros" />
                    </div>
                    <div>
                        <flux:input label="Nombre de garages" type="number" wire:model.live="item.nombre_garages"
                            placeholder="Nombre de garages" />
                    </div>
                    <div>
                        <flux:input label="Année de construction" type="number" wire:model.live="item.annee_construction"
                            placeholder="Année de construction" />
                    </div>
                    <div>   
                        <flux:input label="Type de papier" wire:model.live="item.type_papier"
                            placeholder="Type de papier pour les terrains" />
                    </div>
                    
                    <div class="col-span-2">
                        <flux:textarea label="Source vidéo (Iframe)" wire:model.live="item.source_video"
                            placeholder="Source de la vidéo" rows="4" />
                    </div>
                    <div>
                        <flux:select variant="listbox" label="Statut" placeholder="Sélectionnez un statut..."
                            wire:model.live="item.statut">
                            <flux:select.option value="disponible">Disponible</flux:select.option>
                            <flux:select.option value="vendu">Vendu</flux:select.option>
                        </flux:select>
                    </div>
                    <div class="flex items-center">
                        <flux:checkbox label="Premium" wire:model.live="item.premium" />
                    </div>
                </div>
                <div class="flex mt-4">
                    <flux:spacer />
                    <div class="flex gap-2">
                        <flux:button type="submit" variant="primary">Enregistrer </flux:button>
                        <flux:button type="button" variant="danger" x-on:click="$flux.modal('form-bien').close()">
                            Annuler</flux:button>
                    </div>
                </div>
            </form>
        </div>
    </flux:modal>
    <flux:modal name="change-statut" class="min-w-[22rem]">
        <div class="space-y-6">
            <div>
                <flux:heading size="lg">Changer le statut du bien?</flux:heading>

                <flux:subheading>
                    <p>Vous êtes sur le point de changer le statut du bien.</p>
                </flux:subheading>
            </div>

            <div class="flex gap-2">
                <flux:spacer />

                <flux:modal.close>
                    <flux:button variant="ghost">Annuler</flux:button>
                </flux:modal.close>

                <flux:button type="submit" variant="primary" wire:click="changeStatut">Changer le statut</flux:button>
            </div>
        </div>
    </flux:modal>
    <flux:modal name="images-bien" class="max-w-[120rem]" variant="flyout">
        <div class="space-y-6">
            <flux:heading size="lg">Images du bien</flux:heading>
            <div class="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-4 w-full max-w-[60rem]">
                @foreach ($imagesBienToShow as $image)
                    @if ($image)
                        <div class="relative group overflow-hidden rounded-lg shadow-md hover:shadow-lg transition-all duration-300 ">
                            <img src="{{ asset('storage/' . $image->url) }}" class="w-full h-48 object-cover" alt="Image du bien" />
                            <div class="absolute inset-0 bg-opacity-0 group-hover:bg-opacity-30 transition-all duration-300 flex items-center justify-center">
                                <flux:button variant="danger" square
                                    class="opacity-0 group-hover:opacity-100 transition-opacity duration-300"
                                    wire:click="deleteImage({{ $image->id }})">
                                    <flux:icon icon="trash" variant="micro" />
                                </flux:button>
                            </div>
                        </div>
                    @endif
                @endforeach
            </div>
            <flux:separator />

            <flux:heading size="lg" class="mt-4">Ajouter des images</flux:heading>

            <div>
                <flux:input type="file" wire:model.live="imagesToAdd" label="Ajouter des images" multiple />
            </div>
            

            {{-- afficher les images uploadées --}}
            
            <div class="flex flex-wrap gap-2">
                @foreach ($imagesToAdd as $image)
                    @if ($image)
                        <img src="{{$image->temporaryUrl()}}" class="w-20" />
                    @endif
                @endforeach
            </div>
            <div>
                <flux:button variant="primary" wire:click="saveImages">Enregistrer</flux:button>
            </div>
        </div>
    </flux:modal>
</div>
