<div>
    <h2 class="text-2xl font-bold">Liste des Témoignages</h2>

    <div
        class="flex flex-column sm:flex-row flex-wrap space-y-4 sm:space-y-0 items-center justify-between pb-4 mb-4 mt-4">
        <label for="table-search" class="sr-only">Rechercher</label>
        <div class="relative">
            <div class="absolute inset-y-0 left-0 rtl:inset-r-0 rtl:right-0 flex items-center ps-3 pointer-events-none">
                <svg class="w-5 h-5 text-gray-500 dark:text-gray-400" aria-hidden="true" fill="currentColor"
                    viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
                    <path fill-rule="evenodd"
                        d="M8 4a4 4 0 100 8 4 4 0 000-8zM2 8a6 6 0 1110.89 3.476l4.817 4.817a1 1 0 01-1.414 1.414l-4.816-4.816A6 6 0 012 8z"
                        clip-rule="evenodd"></path>
                </svg>
            </div>

            <flux:input icon="magnifying-glass" placeholder="Rechercher un témoignage" wire:model.live="search"
                clearable />

        </div>
        <flux:button variant="primary" wire:click="openModal">Ajouter un témoignage</flux:button>
    </div>
    <div class="shadow-md sm:rounded-lg relative overflow-x-auto p-4">

        <flux:table :paginate="$testimonials">
            <flux:table.columns>
                <flux:table.column>Nom</flux:table.column>
                <flux:table.column>Témoignage</flux:table.column>
                <flux:table.column>Note</flux:table.column>
                <flux:table.column>Action</flux:table.column>
            </flux:table.columns>

            <flux:table.rows>
                @foreach ($testimonials as $testimonial)
                    <flux:table.row :key="$testimonial->id">
                        <flux:table.cell class="flex items-center gap-3">
                            {{ $testimonial->name }}
                        </flux:table.cell>
                        <flux:table.cell>{{ \Illuminate\Support\Str::limit(strip_tags($testimonial->testimonial), 100, '...') }}</flux:table.cell>
                        <flux:table.cell>{{ $testimonial->rating }}</flux:table.cell>
                        <flux:table.cell>
                            <div class="flex gap-2">
                                <flux:button wire:click="openModal({{ $testimonial->id }})">Modifier</flux:button>
                                <flux:button variant="danger" wire:click="confirmDelete({{ $testimonial->id }})">
                                    <flux:icon name="trash" class="w-4 h-4" />
                                </flux:button>
                            </div>
                        </flux:table.cell>
                    </flux:table.row>
                @endforeach
            </flux:table.rows>
        </flux:table>
    </div>
    <flux:modal name="form-testimonial" class="w-2/3" flyout>
        <div class="space-y-6">
            <div>
                <flux:heading size="lg">
                    @if ($item->id)
                        Modifier un témoignage
                    @else
                        Ajouter un témoignage
                    @endif
                </flux:heading>
            </div>
            <form wire:submit.prevent="save">
                <div class="grid grid-cols-1 gap-4">
                    <div>
                        <flux:input label="Nom" wire:model.live="item.name" placeholder="Votre nom" />
                    </div>
                    <div>
                        <flux:editor label="Témoignage" wire:model.live="item.testimonial" placeholder="Votre témoignage" />
                    </div>
                    <div>
                        <flux:input label="Note" type="number" wire:model.live="item.rating" placeholder="Votre note entre 1 et 5" min="1" max="5" />
                    </div>
                </div>

                <div class="flex mt-4">
                    <flux:spacer />
                    <div class="flex gap-2">
                        <flux:button type="submit" variant="primary">Enregistrer les modifications</flux:button>
                        <flux:button type="button" variant="danger" x-on:click="$flux.modal('form-testimonial').close()">Annuler</flux:button>
                    </div>
                </div>
            </form>
        </div>
    </flux:modal>
    <flux:modal name="delete-testimonial" class="min-w-[22rem]">
    <div class="space-y-6">
        <div>
            <flux:heading size="lg">Supprimer un témoignage?</flux:heading>

            <flux:subheading>
                <p>Vous êtes sur le point de supprimer ce témoignage.</p>
                <p>Cette action ne peut pas être annulée.</p>
            </flux:subheading>
        </div>

        <div class="flex gap-2">
            <flux:spacer />

            <flux:modal.close>
                <flux:button variant="ghost">Annuler</flux:button>
            </flux:modal.close>

            <flux:button type="button" wire:click="delete()" variant="danger">Supprimer le témoignage</flux:button>
        </div>
    </div>
</flux:modal>
</div>
